Summary:	A tool for managing OCI containers and pods
Name:		podman
Version:	3.4.4
Release:	1
License:	Apache v2.0
Group:		Applications/System
#Source0Download: https://github.com/containers/podman/releases
Source0:	https://github.com/containers/podman/archive/v%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	19edefccc5a3288c34435ae7c2eee513
Source1:	policy.json
Source2:	registries.conf
URL:		https://github.com/containers/podman
BuildRequires:	device-mapper-devel
BuildRequires:	go-md2man
BuildRequires:	golang
BuildRequires:	golang-varlink
BuildRequires:	gpgme-devel
BuildRequires:	libseccomp-devel
BuildRequires:	pkgconfig
BuildRequires:	rpm-build >= 4.6
BuildRequires:	rpmbuild(macros) >= 1.644
BuildRequires:	systemd-devel
Requires:	conmon
Requires:	containernetworking-plugins
Requires:	crun
Suggests:	slirp4netns
Suggests:	uidmap
ExclusiveArch:	%{ix86} %{x8664} %{arm} aarch64 mips64 mips64le ppc64 ppc64le s390x
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		_enable_debug_packages 0

%description
Podman (the POD MANager) is a tool for managing containers and images,
volumes mounted into those containers, and pods made from groups of
containers. Podman is based on libpod, a library for container
lifecycle management that is also contained in this repository. The
libpod library provides APIs for managing containers, pods, container
images, and volumes.

%package -n bash-completion-podman
Summary:	bash-completion for podman
Group:		Applications/Shells
Requires:	%{name} = %{version}-%{release}
Requires:	bash-completion >= 2.0
BuildArch:	noarch

%description -n bash-completion-podman
This package provides bash-completion for podman.

%package -n fish-completion-podman
Summary:	Fish completion for podman command
Group:		Applications/Shells
Requires:	%{name} = %{version}-%{release}
Requires:	fish
BuildArch:	noarch

%description -n fish-completion-podman
Fish completion for podman command.

%package -n zsh-completion-podman
Summary:	Zsh completion for podman command
Group:		Applications/Shells
Requires:	%{name} = %{version}-%{release}
Requires:	zsh
BuildArch:	noarch

%description -n zsh-completion-podman
Zsh completion for podman command.

%prep
%setup -q

%build
%{__make} \
	GO=/usr/bin/go \
	GOPATH=$(pwd)/.gopath \
	PREFIX="%{_prefix}" \
	BINDIR="%{_bindir}" \
	LIBEXECDIR="%{_libexecdir}" \
	MANDIR="%{_mandir}" \
	SHAREDIR_CONTAINERS="%{_datadir}/containers" \
	ETCDIR="%{_sysconfdir}" \
	TMPFILESDIR="%{systemdtmpfilesdir}" \
	SYSTEMDDIR="%{systemdunitdir}" \
	USERSYSTEMDDIR="%{systemduserunitdir}" \
	PYTHON="%{__python3}"

%install
rm -rf $RPM_BUILD_ROOT

install -d $RPM_BUILD_ROOT{%{_sysconfdir}/containers,%{bash_compdir},%{fish_compdir},%{zsh_compdir},%{_sharedstatedir}/containers}

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT \
	PREFIX="%{_prefix}" \
	BINDIR="%{_bindir}" \
	LIBEXECDIR="%{_libexecdir}" \
	MANDIR="%{_mandir}" \
	SHAREDIR_CONTAINERS="%{_datadir}/containers" \
	ETCDIR="%{_sysconfdir}" \
	TMPFILESDIR="%{systemdtmpfilesdir}" \
	SYSTEMDDIR="%{systemdunitdir}" \
	USERSYSTEMDDIR="%{systemduserunitdir}" \
	PYTHON="%{__python3}"

cp -p %{SOURCE1} %{SOURCE2} \
	vendor/github.com/containers/common/pkg/config/containers.conf \
	$RPM_BUILD_ROOT%{_sysconfdir}/containers

%{__sed} -e 's|/var/lib/containers|%{_sharedstatedir}/containers|g' \
	vendor/github.com/containers/storage/storage.conf \
        > $RPM_BUILD_ROOT%{_sysconfdir}/containers/storage.conf

$RPM_BUILD_ROOT%{_bindir}/podman completion -f $RPM_BUILD_ROOT%{bash_compdir}/podman bash
$RPM_BUILD_ROOT%{_bindir}/podman completion -f $RPM_BUILD_ROOT%{fish_compdir}/podman.fish fish
$RPM_BUILD_ROOT%{_bindir}/podman completion -f $RPM_BUILD_ROOT%{zsh_compdir}/_podman zsh

%clean
rm -rf $RPM_BUILD_ROOT

%post
%systemd_post podman.service podman.socket

%preun
%systemd_preun podman.service podman.socket

%postun
%systemd_reload

%files
%defattr(644,root,root,755)
%doc README.md
%dir %{_sysconfdir}/containers
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/containers/containers.conf
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/containers/policy.json
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/containers/registries.conf
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/containers/storage.conf
%attr(755,root,root) %{_bindir}/podman
%attr(755,root,root) %{_bindir}/podman-remote
%{systemdunitdir}/podman.service
%{systemdunitdir}/podman.socket
%{systemdunitdir}/podman-auto-update.service
%{systemdunitdir}/podman-auto-update.timer
%{systemdunitdir}/podman-restart.service
%{systemduserunitdir}/podman.service
%{systemduserunitdir}/podman.socket
%{systemduserunitdir}/podman-auto-update.service
%{systemduserunitdir}/podman-auto-update.timer
%{systemduserunitdir}/podman-restart.service
%{_mandir}/man1/podman*.1*
%{_mandir}/man5/oci-hooks.5*
/usr/lib/tmpfiles.d/podman.conf
%dir %{_sharedstatedir}/containers

%files -n bash-completion-podman
%defattr(644,root,root,755)
%{bash_compdir}/podman

%files -n fish-completion-%{name}
%defattr(644,root,root,755)
%{fish_compdir}/podman.fish

%files -n zsh-completion-%{name}
%defattr(644,root,root,755)
%{zsh_compdir}/_podman
%changelog
* Wed Dec 08 2021 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/podman.git;a=log;h=master

* Wed Dec 08 2021 Jan Palus <atler@pld-linux.org> 32054fb
- up to 3.4.4

* Tue Dec 07 2021 Jan Palus <atler@pld-linux.org> 8f4594b
- up to 3.4.3 (fixes CVE-2021-4024 CVE-2021-41190)

* Sun Nov 14 2021 Jan Palus <atler@pld-linux.org> 87f1b1c
- up to 3.4.2

* Fri Nov 05 2021 Jan Palus <atler@pld-linux.org> e6acc51
- macros for %systemd*

* Fri Nov 05 2021 Jan Palus <atler@pld-linux.org> 8a009d3
- disable debug packages

* Fri Nov 05 2021 Jan Palus <atler@pld-linux.org> b74ba7e
- handle systemd units

* Fri Nov 05 2021 Jan Palus <atler@pld-linux.org> ad6ad31
- package default containers.conf and storage.conf

* Wed Oct 20 2021 Jan Palus <atler@pld-linux.org> b879c76
- up to 3.4.1

* Thu Sep 30 2021 Jan Palus <atler@pld-linux.org> c22a6ef
- up to 3.4.0

* Tue Aug 31 2021 Jan Palus <atler@pld-linux.org> 8387ce0
- up to 3.3.1

* Sun Aug 22 2021 Jan Palus <atler@pld-linux.org> 4128685
- up to 3.3.0

* Sun Jul 18 2021 Jan Palus <atler@pld-linux.org> eda51c4
- up to 3.2.3 (fixes CVE-2021-3602)

* Sat Jun 26 2021 Jan Palus <atler@pld-linux.org> 488b519
- up to 3.2.2

* Mon Jun 14 2021 Jan Palus <atler@pld-linux.org> dad5197
- up to 3.2.1

* Mon Jun 14 2021 Jan Palus <atler@pld-linux.org> 84ee773
- one more missing syscall for 32bit platforms

* Fri Jun 04 2021 Jan Palus <atler@pld-linux.org> fe4ccd7
- up to 3.2.0

* Wed Jun 02 2021 Jan Palus <atler@pld-linux.org> 096dadf
- upstream patch allowing more syscalls in seccomp policy for 32bit platforms

* Mon May 31 2021 Jan Palus <atler@pld-linux.org> cbf5965
- updated deps

* Sun May 30 2021 Jan Palus <atler@pld-linux.org> 93c7225
- generate and package shell completions

* Thu May 13 2021 Jan Palus <atler@pld-linux.org> 00346cb
- add basic registries.conf file with docker.io

